==> vtk6-6.3.0-5-aarch64.pkg.tar.xz: vtk/vtkDelimitedTextReader.java <==
// java wrapper for vtkDelimitedTextReader object
//

package vtk;
import vtk.*;

public class vtkDelimitedTextReader extends vtkTableAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native String GetFileName_2();
  public String GetFileName()
    { return GetFileName_2(); }

  private native void SetFileName_3(String id0);
  public void SetFileName(String id0)
    { SetFileName_3(id0); }

  private native void SetInputString_4(String id0);
  public void SetInputString(String id0)
    { SetInputString_4(id0); }

  private native String GetInputString_5();
  public String GetInputString()
    { return GetInputString_5(); }

  private native void SetInputString_6(String id0,int id1);
  public void SetInputString(String id0,int id1)
    { SetInputString_6(id0,id1); }

  private native int GetInputStringLength_7();
  public int GetInputStringLength()
    { return GetInputStringLength_7(); }

  private native void SetReadFromInputString_8(int id0);
  public void SetReadFromInputString(int id0)
    { SetReadFromInputString_8(id0); }

  private native int GetReadFromInputString_9();
  public int GetReadFromInputString()
    { return GetReadFromInputString_9(); }

  private native void ReadFromInputStringOn_10();
  public void ReadFromInputStringOn()
    { ReadFromInputStringOn_10(); }

  private native void ReadFromInputStringOff_11();
  public void ReadFromInputStringOff()
    { ReadFromInputStringOff_11(); }

  private native String GetUnicodeCharacterSet_12();
  public String GetUnicodeCharacterSet()
    { return GetUnicodeCharacterSet_12(); }

  private native void SetUnicodeCharacterSet_13(String id0);
  public void SetUnicodeCharacterSet(String id0)
    { SetUnicodeCharacterSet_13(id0); }

  private native void SetUTF8RecordDelimiters_14(String id0);
  public void SetUTF8RecordDelimiters(String id0)
    { SetUTF8RecordDelimiters_14(id0); }

  private native String GetUTF8RecordDelimiters_15();
  public String GetUTF8RecordDelimiters()
    { return GetUTF8RecordDelimiters_15(); }

  private native void SetFieldDelimiterCharacters_16(String id0);
  public void SetFieldDelimiterCharacters(String id0)
    { SetFieldDelimiterCharacters_16(id0); }

  private native String GetFieldDelimiterCharacters_17();
  public String GetFieldDelimiterCharacters()
    { return GetFieldDelimiterCharacters_17(); }

  private native void SetUTF8FieldDelimiters_18(String id0);
  public void SetUTF8FieldDelimiters(String id0)
    { SetUTF8FieldDelimiters_18(id0); }

  private native String GetUTF8FieldDelimiters_19();
  public String GetUTF8FieldDelimiters()
    { return GetUTF8FieldDelimiters_19(); }

  private native char GetStringDelimiter_20();
  public char GetStringDelimiter()
    { return GetStringDelimiter_20(); }

  private native void SetStringDelimiter_21(char id0);
  public void SetStringDelimiter(char id0)
    { SetStringDelimiter_21(id0); }

  private native void SetUTF8StringDelimiters_22(String id0);
  public void SetUTF8StringDelimiters(String id0)
    { SetUTF8StringDelimiters_22(id0); }

  private native String GetUTF8StringDelimiters_23();
  public String GetUTF8StringDelimiters()
    { return GetUTF8StringDelimiters_23(); }

  private native void SetUseStringDelimiter_24(boolean id0);
  public void SetUseStringDelimiter(boolean id0)
    { SetUseStringDelimiter_24(id0); }

  private native boolean GetUseStringDelimiter_25();
  public boolean GetUseStringDelimiter()
    { return GetUseStringDelimiter_25(); }

  private native void UseStringDelimiterOn_26();
  public void UseStringDelimiterOn()
    { UseStringDelimiterOn_26(); }

  private native void UseStringDelimiterOff_27();
  public void UseStringDelimiterOff()
    { UseStringDelimiterOff_27(); }

  private native boolean GetHaveHeaders_28();
  public boolean GetHaveHeaders()
    { return GetHaveHeaders_28(); }

  private native void SetHaveHeaders_29(boolean id0);
  public void SetHaveHeaders(boolean id0)
    { SetHaveHeaders_29(id0); }

  private native void SetMergeConsecutiveDelimiters_30(boolean id0);
  public void SetMergeConsecutiveDelimiters(boolean id0)
    { SetMergeConsecutiveDelimiters_30(id0); }

  private native boolean GetMergeConsecutiveDelimiters_31();
  public boolean GetMergeConsecutiveDelimiters()
    { return GetMergeConsecutiveDelimiters_31(); }

  private native void MergeConsecutiveDelimitersOn_32();
  public void MergeConsecutiveDelimitersOn()
    { MergeConsecutiveDelimitersOn_32(); }

  private native void MergeConsecutiveDelimitersOff_33();
  public void MergeConsecutiveDelimitersOff()
    { MergeConsecutiveDelimitersOff_33(); }

  private native int GetMaxRecords_34();
  public int GetMaxRecords()
    { return GetMaxRecords_34(); }

  private native void SetMaxRecords_35(int id0);
  public void SetMaxRecords(int id0)
    { SetMaxRecords_35(id0); }

  private native void SetDetectNumericColumns_36(boolean id0);
  public void SetDetectNumericColumns(boolean id0)
    { SetDetectNumericColumns_36(id0); }

  private native boolean GetDetectNumericColumns_37();
  public boolean GetDetectNumericColumns()
    { return GetDetectNumericColumns_37(); }

  private native void DetectNumericColumnsOn_38();
  public void DetectNumericColumnsOn()
    { DetectNumericColumnsOn_38(); }

  private native void DetectNumericColumnsOff_39();
  public void DetectNumericColumnsOff()
    { DetectNumericColumnsOff_39(); }

  private native void SetForceDouble_40(boolean id0);
  public void SetForceDouble(boolean id0)
    { SetForceDouble_40(id0); }

  private native boolean GetForceDouble_41();
  public boolean GetForceDouble()
    { return GetForceDouble_41(); }

  private native void ForceDoubleOn_42();
  public void ForceDoubleOn()
    { ForceDoubleOn_42(); }

  private native void ForceDoubleOff_43();
  public void ForceDoubleOff()
    { ForceDoubleOff_43(); }

  private native void SetTrimWhitespacePriorToNumericConversion_44(boolean id0);
  public void SetTrimWhitespacePriorToNumericConversion(boolean id0)
    { SetTrimWhitespacePriorToNumericConversion_44(id0); }

  private native boolean GetTrimWhitespacePriorToNumericConversion_45();
  public boolean GetTrimWhitespacePriorToNumericConversion()
    { return GetTrimWhitespacePriorToNumericConversion_45(); }

  private native void TrimWhitespacePriorToNumericConversionOn_46();
  public void TrimWhitespacePriorToNumericConversionOn()
    { TrimWhitespacePriorToNumericConversionOn_46(); }

  private native void TrimWhitespacePriorToNumericConversionOff_47();
  public void TrimWhitespacePriorToNumericConversionOff()
    { TrimWhitespacePriorToNumericConversionOff_47(); }

  private native void SetDefaultIntegerValue_48(int id0);
  public void SetDefaultIntegerValue(int id0)
    { SetDefaultIntegerValue_48(id0); }

  private native int GetDefaultIntegerValue_49();
  public int GetDefaultIntegerValue()
    { return GetDefaultIntegerValue_49(); }

  private native void SetDefaultDoubleValue_50(double id0);
  public void SetDefaultDoubleValue(double id0)
    { SetDefaultDoubleValue_50(id0); }

  private native double GetDefaultDoubleValue_51();
  public double GetDefaultDoubleValue()
    { return GetDefaultDoubleValue_51(); }

  private native void SetPedigreeIdArrayName_52(String id0);
  public void SetPedigreeIdArrayName(String id0)
    { SetPedigreeIdArrayName_52(id0); }

  private native String GetPedigreeIdArrayName_53();
  public String GetPedigreeIdArrayName()
    { return GetPedigreeIdArrayName_53(); }

  private native void SetGeneratePedigreeIds_54(boolean id0);
  public void SetGeneratePedigreeIds(boolean id0)
    { SetGeneratePedigreeIds_54(id0); }

  private native boolean GetGeneratePedigreeIds_55();
  public boolean GetGeneratePedigreeIds()
    { return GetGeneratePedigreeIds_55(); }

  private native void GeneratePedigreeIdsOn_56();
  public void GeneratePedigreeIdsOn()
    { GeneratePedigreeIdsOn_56(); }

  private native void GeneratePedigreeIdsOff_57();
  public void GeneratePedigreeIdsOff()
    { GeneratePedigreeIdsOff_57(); }

  private native void SetOutputPedigreeIds_58(boolean id0);
  public void SetOutputPedigreeIds(boolean id0)
    { SetOutputPedigreeIds_58(id0); }

  private native boolean GetOutputPedigreeIds_59();
  public boolean GetOutputPedigreeIds()
    { return GetOutputPedigreeIds_59(); }

  private native void OutputPedigreeIdsOn_60();
  public void OutputPedigreeIdsOn()
    { OutputPedigreeIdsOn_60(); }

  private native void OutputPedigreeIdsOff_61();
  public void OutputPedigreeIdsOff()
    { OutputPedigreeIdsOff_61(); }

  private native String GetLastError_62();
  public String GetLastError()
    { return GetLastError_62(); }

  private native void SetReplacementCharacter_63(int id0);
  public void SetReplacementCharacter(int id0)
    { SetReplacementCharacter_63(id0); }

  private native int GetReplacementCharacter_64();
  public int GetReplacementCharacter()
    { return GetReplacementCharacter_64(); }

  public vtkDelimitedTextReader() { super(); }

  public vtkDelimitedTextReader(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.0.1-3-aarch64.pkg.tar.xz: vtk/vtkDelimitedTextReader.java <==
// java wrapper for vtkDelimitedTextReader object
//

package vtk;
import vtk.*;

public class vtkDelimitedTextReader extends vtkTableAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native String GetFileName_2();
  public String GetFileName()
    { return GetFileName_2(); }

  private native void SetFileName_3(String id0);
  public void SetFileName(String id0)
    { SetFileName_3(id0); }

  private native void SetInputString_4(String id0);
  public void SetInputString(String id0)
    { SetInputString_4(id0); }

  private native String GetInputString_5();
  public String GetInputString()
    { return GetInputString_5(); }

  private native void SetInputString_6(String id0,int id1);
  public void SetInputString(String id0,int id1)
    { SetInputString_6(id0,id1); }

  private native int GetInputStringLength_7();
  public int GetInputStringLength()
    { return GetInputStringLength_7(); }

  private native void SetReadFromInputString_8(int id0);
  public void SetReadFromInputString(int id0)
    { SetReadFromInputString_8(id0); }

  private native int GetReadFromInputString_9();
  public int GetReadFromInputString()
    { return GetReadFromInputString_9(); }

  private native void ReadFromInputStringOn_10();
  public void ReadFromInputStringOn()
    { ReadFromInputStringOn_10(); }

  private native void ReadFromInputStringOff_11();
  public void ReadFromInputStringOff()
    { ReadFromInputStringOff_11(); }

  private native String GetUnicodeCharacterSet_12();
  public String GetUnicodeCharacterSet()
    { return GetUnicodeCharacterSet_12(); }

  private native void SetUnicodeCharacterSet_13(String id0);
  public void SetUnicodeCharacterSet(String id0)
    { SetUnicodeCharacterSet_13(id0); }

  private native void SetUTF8RecordDelimiters_14(String id0);
  public void SetUTF8RecordDelimiters(String id0)
    { SetUTF8RecordDelimiters_14(id0); }

  private native String GetUTF8RecordDelimiters_15();
  public String GetUTF8RecordDelimiters()
    { return GetUTF8RecordDelimiters_15(); }

  private native void SetFieldDelimiterCharacters_16(String id0);
  public void SetFieldDelimiterCharacters(String id0)
    { SetFieldDelimiterCharacters_16(id0); }

  private native String GetFieldDelimiterCharacters_17();
  public String GetFieldDelimiterCharacters()
    { return GetFieldDelimiterCharacters_17(); }

  private native void SetUTF8FieldDelimiters_18(String id0);
  public void SetUTF8FieldDelimiters(String id0)
    { SetUTF8FieldDelimiters_18(id0); }

  private native String GetUTF8FieldDelimiters_19();
  public String GetUTF8FieldDelimiters()
    { return GetUTF8FieldDelimiters_19(); }

  private native char GetStringDelimiter_20();
  public char GetStringDelimiter()
    { return GetStringDelimiter_20(); }

  private native void SetStringDelimiter_21(char id0);
  public void SetStringDelimiter(char id0)
    { SetStringDelimiter_21(id0); }

  private native void SetUTF8StringDelimiters_22(String id0);
  public void SetUTF8StringDelimiters(String id0)
    { SetUTF8StringDelimiters_22(id0); }

  private native String GetUTF8StringDelimiters_23();
  public String GetUTF8StringDelimiters()
    { return GetUTF8StringDelimiters_23(); }

  private native void SetUseStringDelimiter_24(boolean id0);
  public void SetUseStringDelimiter(boolean id0)
    { SetUseStringDelimiter_24(id0); }

  private native boolean GetUseStringDelimiter_25();
  public boolean GetUseStringDelimiter()
    { return GetUseStringDelimiter_25(); }

  private native void UseStringDelimiterOn_26();
  public void UseStringDelimiterOn()
    { UseStringDelimiterOn_26(); }

  private native void UseStringDelimiterOff_27();
  public void UseStringDelimiterOff()
    { UseStringDelimiterOff_27(); }

  private native boolean GetHaveHeaders_28();
  public boolean GetHaveHeaders()
    { return GetHaveHeaders_28(); }

  private native void SetHaveHeaders_29(boolean id0);
  public void SetHaveHeaders(boolean id0)
    { SetHaveHeaders_29(id0); }

  private native void SetMergeConsecutiveDelimiters_30(boolean id0);
  public void SetMergeConsecutiveDelimiters(boolean id0)
    { SetMergeConsecutiveDelimiters_30(id0); }

  private native boolean GetMergeConsecutiveDelimiters_31();
  public boolean GetMergeConsecutiveDelimiters()
    { return GetMergeConsecutiveDelimiters_31(); }

  private native void MergeConsecutiveDelimitersOn_32();
  public void MergeConsecutiveDelimitersOn()
    { MergeConsecutiveDelimitersOn_32(); }

  private native void MergeConsecutiveDelimitersOff_33();
  public void MergeConsecutiveDelimitersOff()
    { MergeConsecutiveDelimitersOff_33(); }

  private native int GetMaxRecords_34();
  public int GetMaxRecords()
    { return GetMaxRecords_34(); }

  private native void SetMaxRecords_35(int id0);
  public void SetMaxRecords(int id0)
    { SetMaxRecords_35(id0); }

  private native void SetDetectNumericColumns_36(boolean id0);
  public void SetDetectNumericColumns(boolean id0)
    { SetDetectNumericColumns_36(id0); }

  private native boolean GetDetectNumericColumns_37();
  public boolean GetDetectNumericColumns()
    { return GetDetectNumericColumns_37(); }

  private native void DetectNumericColumnsOn_38();
  public void DetectNumericColumnsOn()
    { DetectNumericColumnsOn_38(); }

  private native void DetectNumericColumnsOff_39();
  public void DetectNumericColumnsOff()
    { DetectNumericColumnsOff_39(); }

  private native void SetForceDouble_40(boolean id0);
  public void SetForceDouble(boolean id0)
    { SetForceDouble_40(id0); }

  private native boolean GetForceDouble_41();
  public boolean GetForceDouble()
    { return GetForceDouble_41(); }

  private native void ForceDoubleOn_42();
  public void ForceDoubleOn()
    { ForceDoubleOn_42(); }

  private native void ForceDoubleOff_43();
  public void ForceDoubleOff()
    { ForceDoubleOff_43(); }

  private native void SetTrimWhitespacePriorToNumericConversion_44(boolean id0);
  public void SetTrimWhitespacePriorToNumericConversion(boolean id0)
    { SetTrimWhitespacePriorToNumericConversion_44(id0); }

  private native boolean GetTrimWhitespacePriorToNumericConversion_45();
  public boolean GetTrimWhitespacePriorToNumericConversion()
    { return GetTrimWhitespacePriorToNumericConversion_45(); }

  private native void TrimWhitespacePriorToNumericConversionOn_46();
  public void TrimWhitespacePriorToNumericConversionOn()
    { TrimWhitespacePriorToNumericConversionOn_46(); }

  private native void TrimWhitespacePriorToNumericConversionOff_47();
  public void TrimWhitespacePriorToNumericConversionOff()
    { TrimWhitespacePriorToNumericConversionOff_47(); }

  private native void SetDefaultIntegerValue_48(int id0);
  public void SetDefaultIntegerValue(int id0)
    { SetDefaultIntegerValue_48(id0); }

  private native int GetDefaultIntegerValue_49();
  public int GetDefaultIntegerValue()
    { return GetDefaultIntegerValue_49(); }

  private native void SetDefaultDoubleValue_50(double id0);
  public void SetDefaultDoubleValue(double id0)
    { SetDefaultDoubleValue_50(id0); }

  private native double GetDefaultDoubleValue_51();
  public double GetDefaultDoubleValue()
    { return GetDefaultDoubleValue_51(); }

  private native void SetPedigreeIdArrayName_52(String id0);
  public void SetPedigreeIdArrayName(String id0)
    { SetPedigreeIdArrayName_52(id0); }

  private native String GetPedigreeIdArrayName_53();
  public String GetPedigreeIdArrayName()
    { return GetPedigreeIdArrayName_53(); }

  private native void SetGeneratePedigreeIds_54(boolean id0);
  public void SetGeneratePedigreeIds(boolean id0)
    { SetGeneratePedigreeIds_54(id0); }

  private native boolean GetGeneratePedigreeIds_55();
  public boolean GetGeneratePedigreeIds()
    { return GetGeneratePedigreeIds_55(); }

  private native void GeneratePedigreeIdsOn_56();
  public void GeneratePedigreeIdsOn()
    { GeneratePedigreeIdsOn_56(); }

  private native void GeneratePedigreeIdsOff_57();
  public void GeneratePedigreeIdsOff()
    { GeneratePedigreeIdsOff_57(); }

  private native void SetOutputPedigreeIds_58(boolean id0);
  public void SetOutputPedigreeIds(boolean id0)
    { SetOutputPedigreeIds_58(id0); }

  private native boolean GetOutputPedigreeIds_59();
  public boolean GetOutputPedigreeIds()
    { return GetOutputPedigreeIds_59(); }

  private native void OutputPedigreeIdsOn_60();
  public void OutputPedigreeIdsOn()
    { OutputPedigreeIdsOn_60(); }

  private native void OutputPedigreeIdsOff_61();
  public void OutputPedigreeIdsOff()
    { OutputPedigreeIdsOff_61(); }

  private native String GetLastError_62();
  public String GetLastError()
    { return GetLastError_62(); }

  private native void SetReplacementCharacter_63(int id0);
  public void SetReplacementCharacter(int id0)
    { SetReplacementCharacter_63(id0); }

  private native int GetReplacementCharacter_64();
  public int GetReplacementCharacter()
    { return GetReplacementCharacter_64(); }

  public vtkDelimitedTextReader() { super(); }

  public vtkDelimitedTextReader(long id) { super(id); }
  public native long   VTKInit();

}
